(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 11.1' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[     34966,       1071]
NotebookOptionsPosition[     30513,        995]
NotebookOutlinePosition[     30881,       1011]
CellTagsIndexPosition[     30838,       1008]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Derivation of Compositions", "Title",
 CellChangeTimes->{{3.703322463110914*^9, 
  3.7033224821829576`*^9}},ExpressionUUID->"7ba685f8-3530-422b-921e-\
75588b2eb685"],

Cell["\<\
by Rolf Sulanke
Started May  5, 2017
with Mathematica v. 11.1
Revised  December 30,2017
with Mathematica v. 11.2
\
\>", "Text",
 CellChangeTimes->{{3.7033341490429163`*^9, 3.70333421556266*^9}, {
   3.703334498504266*^9, 3.7033345503041353`*^9}, 3.723648378943253*^9, {
   3.72364842505476*^9, 3.7236486021650267`*^9}, {3.723648641572956*^9, 
   3.723648643964858*^9}},ExpressionUUID->"79bf3d1a-1643-41b8-8889-\
ef03bd02268b"],

Cell["\<\
Let us consider a function depending on two kinds of variables:\
\>", "Text",
 CellChangeTimes->{{3.703325523220222*^9, 
  3.703325561964188*^9}},ExpressionUUID->"8324f104-bb7f-45c0-990b-\
5553540b8411"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"x", ",", "y", ",", "z"}], "]"}], "[", 
  RowBox[{"a", ",", "b"}], "]"}]], "Input",
 CellChangeTimes->{
  3.703322948622044*^9, {3.703323289896833*^9, 
   3.7033233402884073`*^9}},ExpressionUUID->"a6cd50f8-bde0-4aee-a96b-\
4fa54dcf0b82"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"x", ",", "y", ",", "z"}], "]"}], "[", 
  RowBox[{"a", ",", "b"}], "]"}]], "Output",
 CellChangeTimes->{3.7033233647299232`*^9, 
  3.703325201662654*^9},ExpressionUUID->"04332c04-be07-47c6-8e65-\
73836218e77e"]
}, Open  ]],

Cell["\<\
Define the Composition, a curve in the 3-space  of coordinates x,y,z:\
\>", "Text",
 CellChangeTimes->{{3.703325599644082*^9, 
  3.703325689235485*^9}},ExpressionUUID->"c890db7a-481d-41df-9b76-\
ac58af3e8dad"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ff", "[", "t_", "]"}], "[", 
   RowBox[{"a_", ",", "b_"}], "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"f", "[", 
    RowBox[{
     RowBox[{"hx", "[", "t", "]"}], ",", 
     RowBox[{"hy", "[", "t", "]"}], ",", 
     RowBox[{"hz", "[", "t", "]"}]}], "]"}], "[", 
   RowBox[{"a", ",", "b"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.703323368702084*^9, 
  3.703323504367791*^9}},ExpressionUUID->"65b649c6-133b-4404-bcf2-\
7c28758e6edc"],

Cell["Now differentiate with respect to t:", "Text",
 CellChangeTimes->{{3.703326020641382*^9, 3.7033260549286213`*^9}, {
  3.703326183951701*^9, 
  3.703326206751734*^9}},ExpressionUUID->"7852d174-2322-4329-9778-\
e9679c8b5cc7"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", "FF", "]"}], ";", 
  RowBox[{
   RowBox[{
    RowBox[{"FF", "[", "t_", "]"}], "[", 
    RowBox[{"a_", ",", "b_"}], "]"}], "=", 
   RowBox[{
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"ff", "[", "s", "]"}], "[", 
       RowBox[{"a", ",", "b"}], "]"}], ",", "s"}], "]"}], "/.", 
    RowBox[{"s", "\[Rule]", "t"}]}]}]}]], "Input",
 CellChangeTimes->{{3.703323515507532*^9, 3.703323549110723*^9}, {
  3.7033270342924337`*^9, 3.703327103377482*^9}, {3.7033271354743967`*^9, 
  3.7033271464813433`*^9}},ExpressionUUID->"f036d552-8535-4aee-891b-\
50c358f6eabd"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{
      SuperscriptBox["hz", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox["f", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"hx", "[", "t", "]"}], ",", 
       RowBox[{"hy", "[", "t", "]"}], ",", 
       RowBox[{"hz", "[", "t", "]"}]}], "]"}]}], "+", 
    RowBox[{
     RowBox[{
      SuperscriptBox["hy", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox["f", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"hx", "[", "t", "]"}], ",", 
       RowBox[{"hy", "[", "t", "]"}], ",", 
       RowBox[{"hz", "[", "t", "]"}]}], "]"}]}], "+", 
    RowBox[{
     RowBox[{
      SuperscriptBox["hx", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox["f", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"hx", "[", "t", "]"}], ",", 
       RowBox[{"hy", "[", "t", "]"}], ",", 
       RowBox[{"hz", "[", "t", "]"}]}], "]"}]}]}], ")"}], "[", 
  RowBox[{"a", ",", "b"}], "]"}]], "Output",
 CellChangeTimes->{3.703323550730101*^9, 3.7033252210879927`*^9, 
  3.703327105079084*^9, 3.703327148280843*^9, 
  3.723647273357373*^9},ExpressionUUID->"7c0072dd-21e2-4ce0-8d15-\
9ef1d7c5e976"]
}, Open  ]],

Cell["The result is nonsense, since the function", "Text",
 CellChangeTimes->{{3.703326222119608*^9, 3.703326299598751*^9}, {
   3.70332635115879*^9, 3.7033263642381697`*^9}, {3.703326409151141*^9, 
   3.7033264425778503`*^9}, {3.703326472765465*^9, 3.70332651600541*^9}, 
   3.703327193736247*^9},ExpressionUUID->"66fed1d2-7084-42e3-8189-\
33f5567719b6"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{
      SuperscriptBox["hz", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox["f", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"hx", "[", "t", "]"}], ",", 
       RowBox[{"hy", "[", "t", "]"}], ",", 
       RowBox[{"hz", "[", "t", "]"}]}], "]"}]}], "+", 
    RowBox[{
     RowBox[{
      SuperscriptBox["hy", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox["f", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"hx", "[", "t", "]"}], ",", 
       RowBox[{"hy", "[", "t", "]"}], ",", 
       RowBox[{"hz", "[", "t", "]"}]}], "]"}]}], "+", 
    RowBox[{
     RowBox[{
      SuperscriptBox["hx", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox["f", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"hx", "[", "t", "]"}], ",", 
       RowBox[{"hy", "[", "t", "]"}], ",", 
       RowBox[{"hz", "[", "t", "]"}]}], "]"}]}]}], ")"}], "[", 
  RowBox[{"a", ",", "b"}], "]"}]], "Input",
 CellChangeTimes->{{3.70332652012361*^9, 3.703326527654496*^9}, {
  3.703326570534498*^9, 3.703326576206668*^9}, {3.7033272038984118`*^9, 
  3.703327223888253*^9}},ExpressionUUID->"f5500f20-c772-4d6d-bbeb-\
2a9fe0dbc58c"],

Cell["isn\[CloseCurlyQuote]t defined. The correct result would be", "Text",
 CellChangeTimes->{{3.7033266423403597`*^9, 3.703326705044084*^9}, {
  3.703327235463874*^9, 
  3.7033272379037724`*^9}},ExpressionUUID->"b5dafa61-b0e9-4e34-a6ce-\
f3f24f9891a1"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Ff", "[", "t_", "]"}], "[", 
   RowBox[{"a_", ",", "b_"}], "]"}], " ", "=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{
     SuperscriptBox["hz", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], " ", 
    RowBox[{
     RowBox[{
      SuperscriptBox["f", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"hx", "[", "t", "]"}], ",", 
       RowBox[{"hy", "[", "t", "]"}], ",", 
       RowBox[{"hz", "[", "t", "]"}]}], "]"}], "[", 
     RowBox[{"a", ",", "b"}], "]"}]}], "+", 
   RowBox[{
    RowBox[{
     SuperscriptBox["hy", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], " ", 
    RowBox[{
     RowBox[{
      SuperscriptBox["f", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"hx", "[", "t", "]"}], ",", 
       RowBox[{"hy", "[", "t", "]"}], ",", 
       RowBox[{"hz", "[", "t", "]"}]}], "]"}], "[", 
     RowBox[{"a", ",", "b"}], "]"}]}], "+", 
   RowBox[{
    RowBox[{
     SuperscriptBox["hx", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], " ", 
    RowBox[{
     RowBox[{
      SuperscriptBox["f", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"hx", "[", "t", "]"}], ",", 
       RowBox[{"hy", "[", "t", "]"}], ",", 
       RowBox[{"hz", "[", "t", "]"}]}], "]"}], "[", 
     RowBox[{"a", ",", "b"}], "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.703326765952629*^9, 3.7033268254791822`*^9}, {
  3.7033268629335833`*^9, 
  3.703326877941976*^9}},ExpressionUUID->"1416b61c-9cfc-4e7e-a0e6-\
28f0ce6a33c9"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    SuperscriptBox["hz", "\[Prime]",
     MultilineFunction->None], "[", "t", "]"}], " ", 
   RowBox[{
    RowBox[{
     SuperscriptBox["f", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      RowBox[{"hx", "[", "t", "]"}], ",", 
      RowBox[{"hy", "[", "t", "]"}], ",", 
      RowBox[{"hz", "[", "t", "]"}]}], "]"}], "[", 
    RowBox[{"a", ",", "b"}], "]"}]}], "+", 
  RowBox[{
   RowBox[{
    SuperscriptBox["hy", "\[Prime]",
     MultilineFunction->None], "[", "t", "]"}], " ", 
   RowBox[{
    RowBox[{
     SuperscriptBox["f", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      RowBox[{"hx", "[", "t", "]"}], ",", 
      RowBox[{"hy", "[", "t", "]"}], ",", 
      RowBox[{"hz", "[", "t", "]"}]}], "]"}], "[", 
    RowBox[{"a", ",", "b"}], "]"}]}], "+", 
  RowBox[{
   RowBox[{
    SuperscriptBox["hx", "\[Prime]",
     MultilineFunction->None], "[", "t", "]"}], " ", 
   RowBox[{
    RowBox[{
     SuperscriptBox["f", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "0", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      RowBox[{"hx", "[", "t", "]"}], ",", 
      RowBox[{"hy", "[", "t", "]"}], ",", 
      RowBox[{"hz", "[", "t", "]"}]}], "]"}], "[", 
    RowBox[{"a", ",", "b"}], "]"}]}]}]], "Output",
 CellChangeTimes->{
  3.703326891808667*^9},ExpressionUUID->"15cb17d4-08d5-47b7-ab8f-\
b104ac9a4d6c"]
}, Open  ]],

Cell["Mathematica does not identify the functions:", "Text",
 CellChangeTimes->{{3.703328157525038*^9, 
  3.703328262831523*^9}},ExpressionUUID->"1d55361f-592d-4f0b-bcea-\
04c6964a573a"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"FF", "[", "t", "]"}], "[", 
    RowBox[{"a", ",", "b"}], "]"}], "==", 
   RowBox[{
    RowBox[{"Ff", "[", "t", "]"}], "[", 
    RowBox[{"a", ",", "b"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.703326924270998*^9, 3.703326933226824*^9}, {
  3.703327288583824*^9, 3.703327345767288*^9}, {3.703327376224893*^9, 
  3.703327432767035*^9}, {3.703328121538391*^9, 
  3.703328129600903*^9}},ExpressionUUID->"b06d33a6-b771-4242-bb72-\
7f923790e91c"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     SuperscriptBox["hz", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], " ", 
    RowBox[{
     RowBox[{
      SuperscriptBox["f", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"hx", "[", "t", "]"}], ",", 
       RowBox[{"hy", "[", "t", "]"}], ",", 
       RowBox[{"hz", "[", "t", "]"}]}], "]"}], "[", 
     RowBox[{"a", ",", "b"}], "]"}]}], "+", 
   RowBox[{
    RowBox[{
     SuperscriptBox["hy", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], " ", 
    RowBox[{
     RowBox[{
      SuperscriptBox["f", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"hx", "[", "t", "]"}], ",", 
       RowBox[{"hy", "[", "t", "]"}], ",", 
       RowBox[{"hz", "[", "t", "]"}]}], "]"}], "[", 
     RowBox[{"a", ",", "b"}], "]"}]}], "+", 
   RowBox[{
    RowBox[{
     SuperscriptBox["hx", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], " ", 
    RowBox[{
     RowBox[{
      SuperscriptBox["f", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"hx", "[", "t", "]"}], ",", 
       RowBox[{"hy", "[", "t", "]"}], ",", 
       RowBox[{"hz", "[", "t", "]"}]}], "]"}], "[", 
     RowBox[{"a", ",", "b"}], "]"}]}]}], "\[Equal]", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{
       SuperscriptBox["hz", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], " ", 
      RowBox[{
       SuperscriptBox["f", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{
        RowBox[{"hx", "[", "t", "]"}], ",", 
        RowBox[{"hy", "[", "t", "]"}], ",", 
        RowBox[{"hz", "[", "t", "]"}]}], "]"}]}], "+", 
     RowBox[{
      RowBox[{
       SuperscriptBox["hy", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], " ", 
      RowBox[{
       SuperscriptBox["f", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{
        RowBox[{"hx", "[", "t", "]"}], ",", 
        RowBox[{"hy", "[", "t", "]"}], ",", 
        RowBox[{"hz", "[", "t", "]"}]}], "]"}]}], "+", 
     RowBox[{
      RowBox[{
       SuperscriptBox["hx", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], " ", 
      RowBox[{
       SuperscriptBox["f", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{
        RowBox[{"hx", "[", "t", "]"}], ",", 
        RowBox[{"hy", "[", "t", "]"}], ",", 
        RowBox[{"hz", "[", "t", "]"}]}], "]"}]}]}], ")"}], "[", 
   RowBox[{"a", ",", "b"}], "]"}]}]], "Output",
 CellChangeTimes->{
  3.7033273469666147`*^9, {3.703327377850224*^9, 3.703327390070551*^9}, 
   3.703327434535843*^9, 
   3.703328139066989*^9},ExpressionUUID->"db2592ad-99a3-4973-a7cb-\
2cdf9f1647a0"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"FF", "[", "t", "]"}], "[", 
     RowBox[{"a", ",", "b"}], "]"}], "-", 
    RowBox[{
     RowBox[{"Ff", "[", "t", "]"}], "[", 
     RowBox[{"a", ",", "b"}], "]"}]}], " ", "===", "0"}], "]"}]], "Input",
 CellChangeTimes->{{3.703326924270998*^9, 3.703326933226824*^9}, {
  3.703327288583824*^9, 3.703327345767288*^9}, {3.703327376224893*^9, 
  3.703327464118123*^9}},ExpressionUUID->"68d30fdf-cb5c-4df3-af94-\
b3bf128ff83d"],

Cell[BoxData["False"], "Output",
 CellChangeTimes->{
  3.703327468166129*^9},ExpressionUUID->"19acd83f-5714-4433-bb9c-\
ca9f29ee9424"]
}, Open  ]],

Cell["\<\
Particularly this failure is disturbing in tensor calculus, where a,b appear \
as indices.
Consider the plane vector field\
\>", "Text",
 CellChangeTimes->{{3.7033282816023693`*^9, 
  3.703328409726328*^9}},ExpressionUUID->"e00a98f4-25e2-4c7a-84fa-\
1c6101a556fd"],

Cell[BoxData[
 RowBox[{
  RowBox[{"vw", "[", 
   RowBox[{"x_", ",", "y_"}], "]"}], ":=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Xi]", "[", 
      RowBox[{"x", ",", "y"}], "]"}], "[", "1", "]"}], ",", 
    RowBox[{
     RowBox[{"\[Xi]", "[", 
      RowBox[{"x", ",", "y"}], "]"}], "[", "2", "]"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.703309939543964*^9, 
  3.7033099859679728`*^9}},ExpressionUUID->"42fda6a3-fa10-4314-9594-\
621a049724b5"],

Cell["along the curve", "Text",
 CellChangeTimes->{{3.703328457177245*^9, 
  3.703328472063949*^9}},ExpressionUUID->"4c610ede-ccee-48d0-b97e-\
b1014fa5bb48"],

Cell[BoxData[
 RowBox[{
  RowBox[{"cu", "[", "t_", "]"}], " ", ":=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"hx", "[", "t", "]"}], ",", 
    RowBox[{"hy", "[", "t", "]"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.703310020267798*^9, 3.703310081063048*^9}, {
  3.703328480110368*^9, 
  3.703328505629714*^9}},ExpressionUUID->"8075f675-1fe5-4113-9a4a-\
4e4e7bf0a249"],

Cell[BoxData[
 RowBox[{
  RowBox[{"vwc", "[", "t_", "]"}], ":=", " ", 
  RowBox[{"vw", "[", 
   RowBox[{
    RowBox[{"cu", "[", "t", "]"}], "/.", 
    RowBox[{"List", "\[Rule]", "Sequence"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.70332852143326*^9, 3.703328556661583*^9}, {
  3.703328596733285*^9, 3.70332860653306*^9}, {3.703328644661214*^9, 
  3.703328656364646*^9}, {3.723647586972723*^9, 
  3.723647614054648*^9}},ExpressionUUID->"4d7cbf23-7da2-4e10-b12b-\
4c73dcedefa2"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"vwc", "[", "t", "]"}]], "Input",
 CellChangeTimes->{{3.703328611641844*^9, 3.703328615788875*^9}, 
   3.723647716360585*^9},ExpressionUUID->"2c0d9a2e-1ea9-480b-b44f-\
6e41f9e3b519"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"\[Xi]", "[", 
     RowBox[{
      RowBox[{"hx", "[", "t", "]"}], ",", 
      RowBox[{"hy", "[", "t", "]"}]}], "]"}], "[", "1", "]"}], ",", 
   RowBox[{
    RowBox[{"\[Xi]", "[", 
     RowBox[{
      RowBox[{"hx", "[", "t", "]"}], ",", 
      RowBox[{"hy", "[", "t", "]"}]}], "]"}], "[", "2", "]"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.703328616630549*^9, 3.703328666123928*^9, 
  3.726285602306826*^9},ExpressionUUID->"ab183bff-7124-43c6-aad7-\
83161ff23eaa"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"D", "[", 
  RowBox[{
   RowBox[{"vwc", "[", "t", "]"}], ",", "t"}], "]"}]], "Input",
 CellChangeTimes->{{3.70331010023691*^9, 3.703310140550437*^9}, {
   3.70332869473252*^9, 3.703328719468099*^9}, 
   3.723647718128131*^9},ExpressionUUID->"3c8edc35-d962-4824-baa2-\
89099c570e1d"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        SuperscriptBox["hy", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Xi]", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         RowBox[{"hx", "[", "t", "]"}], ",", 
         RowBox[{"hy", "[", "t", "]"}]}], "]"}]}], "+", 
      RowBox[{
       RowBox[{
        SuperscriptBox["hx", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Xi]", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         RowBox[{"hx", "[", "t", "]"}], ",", 
         RowBox[{"hy", "[", "t", "]"}]}], "]"}]}]}], ")"}], "[", "1", "]"}], 
   ",", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        SuperscriptBox["hy", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Xi]", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         RowBox[{"hx", "[", "t", "]"}], ",", 
         RowBox[{"hy", "[", "t", "]"}]}], "]"}]}], "+", 
      RowBox[{
       RowBox[{
        SuperscriptBox["hx", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Xi]", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         RowBox[{"hx", "[", "t", "]"}], ",", 
         RowBox[{"hy", "[", "t", "]"}]}], "]"}]}]}], ")"}], "[", "2", "]"}]}],
   "}"}]], "Output",
 CellChangeTimes->{3.70331014577003*^9, 3.7033287243347588`*^9, 
  3.72628561327077*^9},ExpressionUUID->"e8b68da8-09d4-440a-b897-cf13869e8508"]
}, Open  ]],

Cell["The result has no sense, the correct result is", "Text",
 CellChangeTimes->{{3.7033288915701427`*^9, 
  3.703328920025872*^9}},ExpressionUUID->"18e2cae7-bf77-4d7f-929e-\
b2fc18481f74"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      SuperscriptBox["hy", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], " ", 
     RowBox[{
      RowBox[{
       SuperscriptBox["\[Xi]", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{
        RowBox[{"hx", "[", "t", "]"}], ",", 
        RowBox[{"hy", "[", "t", "]"}]}], "]"}], "[", "1", "]"}]}], "+", 
    RowBox[{
     RowBox[{
      SuperscriptBox["hx", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], " ", 
     RowBox[{
      RowBox[{
       SuperscriptBox["\[Xi]", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{
        RowBox[{"hx", "[", "t", "]"}], ",", 
        RowBox[{"hy", "[", "t", "]"}]}], "]"}], "[", "1", "]"}]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{
      SuperscriptBox["hy", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], " ", 
     RowBox[{
      RowBox[{
       SuperscriptBox["\[Xi]", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{
        RowBox[{"hx", "[", "t", "]"}], ",", 
        RowBox[{"hy", "[", "t", "]"}]}], "]"}], "[", "2", "]"}]}], "+", 
    RowBox[{
     RowBox[{
      SuperscriptBox["hx", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], " ", 
     RowBox[{
      RowBox[{
       SuperscriptBox["\[Xi]", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{
        RowBox[{"hx", "[", "t", "]"}], ",", 
        RowBox[{"hy", "[", "t", "]"}]}], "]"}], "[", "2", "]"}]}]}]}], 
  "}"}]], "Input",
 CellChangeTimes->{{3.703329202632242*^9, 3.703329266400453*^9}, 
   3.726285478255368*^9, {3.7262856964853687`*^9, 
   3.726285698756753*^9}},ExpressionUUID->"8cb85587-21de-4ce4-9388-\
3ef3db5b4bfa"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      SuperscriptBox["hy", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox["\[Xi]", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{
        RowBox[{"hx", "[", "t", "]"}], "[", "1", "]"}], ",", 
       RowBox[{"hy", "[", "t", "]"}]}], "]"}]}], "+", 
    RowBox[{
     RowBox[{
      SuperscriptBox["hx", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], " ", 
     RowBox[{
      RowBox[{
       SuperscriptBox["\[Xi]", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{
        RowBox[{"hx", "[", "t", "]"}], ",", 
        RowBox[{"hy", "[", "t", "]"}]}], "]"}], "[", "1", "]"}]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{
      SuperscriptBox["hy", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], " ", 
     RowBox[{
      RowBox[{
       SuperscriptBox["\[Xi]", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{
        RowBox[{"hx", "[", "t", "]"}], ",", 
        RowBox[{"hy", "[", "t", "]"}]}], "]"}], "[", "2", "]"}]}], "+", 
    RowBox[{
     RowBox[{
      SuperscriptBox["hx", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], " ", 
     RowBox[{
      RowBox[{
       SuperscriptBox["\[Xi]", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{
        RowBox[{"hx", "[", "t", "]"}], ",", 
        RowBox[{"hy", "[", "t", "]"}]}], "]"}], "[", "2", "]"}]}]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.72364779187668*^9},ExpressionUUID->"3cf9d53b-26a6-4546-9510-c6b9d97a10cd"]
}, Open  ]],

Cell["On the other hand, writing the indices at the first place:", "Text",
 CellChangeTimes->{{3.703329625066874*^9, 
  3.703329683043497*^9}},ExpressionUUID->"5cc72f89-0faa-458f-ab16-\
bcf9a1bc3b2d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", "vw", "]"}], ";", 
  RowBox[{
   RowBox[{"vw", "[", 
    RowBox[{"x_", ",", "y_"}], "]"}], ":=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
      RowBox[{"x", ",", "y"}], "]"}], ",", 
     RowBox[{
      RowBox[{"\[Xi]", "[", "2", "]"}], "[", 
      RowBox[{"x", ",", "y"}], "]"}]}], "}"}]}]}]], "Input",
 CellChangeTimes->{{3.703309939543964*^9, 3.7033099859679728`*^9}, {
  3.703310273750613*^9, 3.703310294942524*^9}, {3.703329367910905*^9, 
  3.703329378870685*^9}},ExpressionUUID->"1bf2fa8a-e5d4-4e39-8228-\
4bd43bde66f2"],

Cell["all runs as expected:", "Text",
 CellChangeTimes->{{3.7033296968994703`*^9, 
  3.7033297120113373`*^9}},ExpressionUUID->"ee74a1af-ec94-4b6f-a292-\
1cb6fe798426"],

Cell[BoxData[
 RowBox[{
  RowBox[{"vwc", "[", "t_", "]"}], ":=", " ", 
  RowBox[{"vw", "[", 
   RowBox[{
    RowBox[{"cu", "[", "t", "]"}], "/.", 
    RowBox[{"List", "\[Rule]", "Sequence"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.70332852143326*^9, 3.703328556661583*^9}, {
   3.703328596733285*^9, 3.70332860653306*^9}, {3.703328644661214*^9, 
   3.703328656364646*^9}, 
   3.723647750888784*^9},ExpressionUUID->"c182399b-03bb-4c44-b168-\
d67c8c428e0b"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"vwc", "[", "t", "]"}]], "Input",
 CellChangeTimes->{{3.703328611641844*^9, 3.703328615788875*^9}, 
   3.723647752687457*^9},ExpressionUUID->"1798fa1a-2005-49fc-8636-\
ec6ec6b479be"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
    RowBox[{
     RowBox[{"hx", "[", "t", "]"}], ",", 
     RowBox[{"hy", "[", "t", "]"}]}], "]"}], ",", 
   RowBox[{
    RowBox[{"\[Xi]", "[", "2", "]"}], "[", 
    RowBox[{
     RowBox[{"hx", "[", "t", "]"}], ",", 
     RowBox[{"hy", "[", "t", "]"}]}], "]"}]}], "}"}]], "Output",
 CellChangeTimes->{3.7033294856418247`*^9, 3.723647823165884*^9, 
  3.726286040192319*^9},ExpressionUUID->"6d0bcdb6-4773-46e7-bba9-\
13c9b41048ea"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"D", "[", 
  RowBox[{
   RowBox[{"vwc", "[", "t", "]"}], ",", "t"}], "]"}]], "Input",
 CellChangeTimes->{{3.70331010023691*^9, 3.703310140550437*^9}, {
   3.70332869473252*^9, 3.703328719468099*^9}, 
   3.723647754151474*^9},ExpressionUUID->"9ebb0294-91f1-475a-bcca-\
dcb199827a43"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      SuperscriptBox["hy", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"\[Xi]", "[", "1", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"hx", "[", "t", "]"}], ",", 
       RowBox[{"hy", "[", "t", "]"}]}], "]"}]}], "+", 
    RowBox[{
     RowBox[{
      SuperscriptBox["hx", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"\[Xi]", "[", "1", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"hx", "[", "t", "]"}], ",", 
       RowBox[{"hy", "[", "t", "]"}]}], "]"}]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{
      SuperscriptBox["hy", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"\[Xi]", "[", "2", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"hx", "[", "t", "]"}], ",", 
       RowBox[{"hy", "[", "t", "]"}]}], "]"}]}], "+", 
    RowBox[{
     RowBox[{
      SuperscriptBox["hx", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"\[Xi]", "[", "2", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"hx", "[", "t", "]"}], ",", 
       RowBox[{"hy", "[", "t", "]"}]}], "]"}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.703329498682543*^9, 3.723647831069456*^9, 
  3.726286053119215*^9},ExpressionUUID->"1c566afc-28f7-45f4-b306-\
ac9c0acd4d1c"]
}, Open  ]],

Cell["\<\
This property of Mathematica is the reason for changing the definition of the \
function tensorfield. 

Done May 9,2017.\
\>", "Text",
 CellChangeTimes->{{3.7033298240739937`*^9, 3.703330188335808*^9}, {
   3.703330248183193*^9, 3.703330273911235*^9}, 3.72364796840308*^9, {
   3.7236480226267643`*^9, 3.723648113777567*^9}, {3.7236482777763863`*^9, 
   3.723648323111764*^9}},ExpressionUUID->"bd367e25-31f0-4132-9e67-\
556264665af2"]
}, Open  ]]
},
WindowSize->{991, 648},
WindowMargins->{{0, Automatic}, {0, Automatic}},
Magnification:>1.25 Inherited,
FrontEndVersion->"11.2 for Linux x86 (64-bit) (September 10, 2017)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 171, 3, 124, "Title",ExpressionUUID->"7ba685f8-3530-422b-921e-75588b2eb685"],
Cell[754, 27, 436, 12, 188, "Text",ExpressionUUID->"79bf3d1a-1643-41b8-8889-ef03bd02268b"],
Cell[1193, 41, 213, 5, 44, "Text",ExpressionUUID->"8324f104-bb7f-45c0-990b-5553540b8411"],
Cell[CellGroupData[{
Cell[1431, 50, 293, 8, 39, "Input",ExpressionUUID->"a6cd50f8-bde0-4aee-a96b-4fa54dcf0b82"],
Cell[1727, 60, 266, 7, 44, "Output",ExpressionUUID->"04332c04-be07-47c6-8e65-73836218e77e"]
}, Open  ]],
Cell[2008, 70, 219, 5, 44, "Text",ExpressionUUID->"c890db7a-481d-41df-9b76-ac58af3e8dad"],
Cell[2230, 77, 483, 14, 39, "Input",ExpressionUUID->"65b649c6-133b-4404-bcf2-7c28758e6edc"],
Cell[2716, 93, 229, 4, 44, "Text",ExpressionUUID->"7852d174-2322-4329-9778-e9679c8b5cc7"],
Cell[CellGroupData[{
Cell[2970, 101, 626, 17, 39, "Input",ExpressionUUID->"f036d552-8535-4aee-891b-50c358f6eabd"],
Cell[3599, 120, 1707, 53, 81, "Output",ExpressionUUID->"7c0072dd-21e2-4ce0-8d15-9ef1d7c5e976"]
}, Open  ]],
Cell[5321, 176, 355, 5, 44, "Text",ExpressionUUID->"66fed1d2-7084-42e3-8189-33f5567719b6"],
Cell[5679, 183, 1733, 53, 76, "Input",ExpressionUUID->"f5500f20-c772-4d6d-bbeb-2a9fe0dbc58c"],
Cell[7415, 238, 254, 4, 44, "Text",ExpressionUUID->"b5dafa61-b0e9-4e34-a6ce-f3f24f9891a1"],
Cell[CellGroupData[{
Cell[7694, 246, 1889, 60, 98, "Input",ExpressionUUID->"1416b61c-9cfc-4e7e-a0e6-28f0ce6a33c9"],
Cell[9586, 308, 1644, 55, 103, "Output",ExpressionUUID->"15cb17d4-08d5-47b7-ab8f-b104ac9a4d6c"]
}, Open  ]],
Cell[11245, 366, 186, 3, 44, "Text",ExpressionUUID->"1d55361f-592d-4f0b-bcea-04c6964a573a"],
Cell[CellGroupData[{
Cell[11456, 373, 529, 13, 39, "Input",ExpressionUUID->"b06d33a6-b771-4242-bb72-7f923790e91c"],
Cell[11988, 388, 3358, 107, 169, "Output",ExpressionUUID->"db2592ad-99a3-4973-a7cb-2cdf9f1647a0"]
}, Open  ]],
Cell[CellGroupData[{
Cell[15383, 500, 516, 13, 39, "Input",ExpressionUUID->"68d30fdf-cb5c-4df3-af94-b3bf128ff83d"],
Cell[15902, 515, 134, 3, 44, "Output",ExpressionUUID->"19acd83f-5714-4433-bb9c-ca9f29ee9424"]
}, Open  ]],
Cell[16051, 521, 274, 7, 73, "Text",ExpressionUUID->"e00a98f4-25e2-4c7a-84fa-1c6101a556fd"],
Cell[16328, 530, 464, 14, 39, "Input",ExpressionUUID->"42fda6a3-fa10-4314-9594-621a049724b5"],
Cell[16795, 546, 157, 3, 44, "Text",ExpressionUUID->"4c610ede-ccee-48d0-b97e-b1014fa5bb48"],
Cell[16955, 551, 374, 10, 39, "Input",ExpressionUUID->"8075f675-1fe5-4113-9a4a-4e4e7bf0a249"],
Cell[17332, 563, 480, 11, 39, "Input",ExpressionUUID->"4d7cbf23-7da2-4e10-b12b-4c73dcedefa2"],
Cell[CellGroupData[{
Cell[17837, 578, 205, 4, 39, "Input",ExpressionUUID->"2c0d9a2e-1ea9-480b-b44f-6e41f9e3b519"],
Cell[18045, 584, 532, 16, 44, "Output",ExpressionUUID->"ab183bff-7124-43c6-aad7-83161ff23eaa"]
}, Open  ]],
Cell[CellGroupData[{
Cell[18614, 605, 305, 7, 39, "Input",ExpressionUUID->"3c8edc35-d962-4824-baa2-89099c570e1d"],
Cell[18922, 614, 2132, 68, 81, "Output",ExpressionUUID->"e8b68da8-09d4-440a-b897-cf13869e8508"]
}, Open  ]],
Cell[21069, 685, 190, 3, 44, "Text",ExpressionUUID->"18e2cae7-bf77-4d7f-929e-b2fc18481f74"],
Cell[CellGroupData[{
Cell[21284, 692, 2124, 69, 76, "Input",ExpressionUUID->"8cb85587-21de-4ce4-9388-3ef3db5b4bfa"],
Cell[23411, 763, 2016, 67, 81, "Output",ExpressionUUID->"3cf9d53b-26a6-4546-9510-c6b9d97a10cd"]
}, Open  ]],
Cell[25442, 833, 200, 3, 44, "Text",ExpressionUUID->"5cc72f89-0faa-458f-ab16-bcf9a1bc3b2d"],
Cell[25645, 838, 623, 17, 39, "Input",ExpressionUUID->"1bf2fa8a-e5d4-4e39-8228-4bd43bde66f2"],
Cell[26271, 857, 167, 3, 44, "Text",ExpressionUUID->"ee74a1af-ec94-4b6f-a292-1cb6fe798426"],
Cell[26441, 862, 459, 11, 39, "Input",ExpressionUUID->"c182399b-03bb-4c44-b168-d67c8c428e0b"],
Cell[CellGroupData[{
Cell[26925, 877, 205, 4, 39, "Input",ExpressionUUID->"1798fa1a-2005-49fc-8636-ec6ec6b479be"],
Cell[27133, 883, 525, 15, 44, "Output",ExpressionUUID->"6d0bcdb6-4773-46e7-bba9-13c9b41048ea"]
}, Open  ]],
Cell[CellGroupData[{
Cell[27695, 903, 305, 7, 39, "Input",ExpressionUUID->"9ebb0294-91f1-475a-bcca-dcb199827a43"],
Cell[28003, 912, 2035, 67, 81, "Output",ExpressionUUID->"1c566afc-28f7-45f4-b306-ac9c0acd4d1c"]
}, Open  ]],
Cell[30053, 982, 444, 10, 102, "Text",ExpressionUUID->"bd367e25-31f0-4132-9e67-556264665af2"]
}, Open  ]]
}
]
*)

